@@ -12,7 +12,7 @@ Readonly::Hash my %LANG => (
 	'title' => 'Page title',
 );
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Constructor.
 sub new {
@@ -54,7 +54,10 @@ sub new {
 sub process {
 	my $self = shift;
 
-	my $css = $self->{'css'}->flush."\n";
+	my $css;
+	if ($self->{'css'}) {
+		$css = $self->{'css'}->flush."\n";
+	}
 
 	# Begin of page.
 	$self->{'tags'}->put(
@@ -259,6 +262,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
